==> haskell-hspec-2.11.4-18.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec
version:              2.11.4
visibility:           public
id:                   hspec-2.11.4-2r49l9VEKrJ4fH7w2ReGM6
key:                  hspec-2.11.4-2r49l9VEKrJ4fH7w2ReGM6
license:              MIT
copyright:
    (c) 2011-2023 Simon Hengel,
    (c) 2011-2012 Trystan Spangler,
    (c) 2011 Greg Weber

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             A Testing Framework for Haskell
description:
    Hspec is a testing framework for Haskell.  Some of Hspec'\''s distinctive
    features are:

    * a friendly DSL for defining tests

    * integration with QuickCheck, SmallCheck, and HUnit

    * parallel test execution

    * automatic discovery of test files

    The Hspec Manual is at <https://hspec.github.io/>.

category:             Testing
abi:                  73b7131435ec8543b1f6ad1062bc6f84
exposed:              True
exposed-modules:
    Test.Hspec Test.Hspec.Discover Test.Hspec.Formatters
    Test.Hspec.QuickCheck Test.Hspec.Runner

hidden-modules:       Paths_hspec
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-2.11.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-2.11.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-2.11.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec
hs-libraries:         HShspec-2.11.4-2r49l9VEKrJ4fH7w2ReGM6
depends:
    QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L base-4.18.2.1
    hspec-core-2.11.4-1HkLPyupJ0H3VqtAEeRZWL
    hspec-discover-2.11.4-CuMTomF9NCUAMeb0nEKVmj
    hspec-expectations-0.8.4-7xRGbz7YGlh8mVR0kjpKwh

haddock-interfaces:   /usr/share/doc/haskell-hspec/html/hspec.haddock
haddock-html:         /usr/share/doc/haskell-hspec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-2.11.4-21-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec
version:              2.11.4
visibility:           public
id:                   hspec-2.11.4-8QgnQwrEho14jh62SRkWei
key:                  hspec-2.11.4-8QgnQwrEho14jh62SRkWei
license:              MIT
copyright:
    (c) 2011-2023 Simon Hengel,
    (c) 2011-2012 Trystan Spangler,
    (c) 2011 Greg Weber

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             A Testing Framework for Haskell
description:
    Hspec is a testing framework for Haskell.  Some of Hspec'\''s distinctive
    features are:

    * a friendly DSL for defining tests

    * integration with QuickCheck, SmallCheck, and HUnit

    * parallel test execution

    * automatic discovery of test files

    The Hspec Manual is at <https://hspec.github.io/>.

category:             Testing
abi:                  becc6c09de9ef6315068847c3e494f87
exposed:              True
exposed-modules:
    Test.Hspec Test.Hspec.Discover Test.Hspec.Formatters
    Test.Hspec.QuickCheck Test.Hspec.Runner

hidden-modules:       Paths_hspec
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-2.11.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-2.11.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-2.11.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec
hs-libraries:         HShspec-2.11.4-8QgnQwrEho14jh62SRkWei
depends:
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS base-4.18.2.1
    hspec-core-2.11.4-LH4ljAyFr7833CkU966kHA
    hspec-discover-2.11.4-BRuJ2uy8IILxA575pcaUh
    hspec-expectations-0.8.4-JRz47SURfXgGxfIuVeuxEa

haddock-interfaces:   /usr/share/doc/haskell-hspec/html/hspec.haddock
haddock-html:         /usr/share/doc/haskell-hspec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
